@@ -38,6 +38,7 @@ print(f'BASE_PATH:{BASE_PATH}')
 
 # SECURITY WARNING: don't run with debug turned on in production!
 DEBUG = False
+TEMPLATE_DEBUG = False
 
 # Serve static/media files by Django?
 # In production Caddy should serve this!
@@ -130,14 +131,45 @@ TEMPLATES = [
     },
 ]
 
+# _____________________________________________________________________________
+
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
+
+# _____________________________________________________________________________
+
+# Mark CSRF cookie as "secure" -> browsers sent cookie only with an HTTPS connection:
+CSRF_COOKIE_SECURE = True
+
+# Mark session cookie as "secure" -> browsers sent cookie only with an HTTPS connection:
+SESSION_COOKIE_SECURE = True
+
+# HTTP header/value combination that signifies a request is secure
+# Your nginx.conf must set "X-Forwarded-Protocol" proxy header!
+SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTOCOL', 'https')
+
+# SecurityMiddleware should redirects all non-HTTPS requests to HTTPS:
+SECURE_SSL_REDIRECT = True
+
+# SecurityMiddleware should preload directive to the HTTP Strict Transport Security header:
+SECURE_HSTS_PRELOAD = True
+
+# Instruct modern browsers to refuse to connect to your domain name via an insecure connection:
+SECURE_HSTS_SECONDS = 3600
+
+# SecurityMiddleware should add the "includeSubDomains" directive to the Strict-Transport-Security
+# header: All subdomains of your domain should be served exclusively via SSL!
+SECURE_HSTS_INCLUDE_SUBDOMAINS = True
+
 # _____________________________________________________________________________
 # Internationalization
 
 LANGUAGE_CODE = 'en'
 
 LANGUAGES = [
+    ('ca', _('Catalan')),
     ('de', _('German')),
     ('en', _('English')),
+    ('es', _('Spanish'))
 ]
 USE_I18N = True
 USE_L10N = True
