@@ -2,8 +2,6 @@
 
 """
     Django settings for local development
-
-
 """
 
 import sys as __sys
@@ -13,7 +11,7 @@ from inventory_project.settings.base import *  # noqa
 
 # SECURITY WARNING: don't run with debug turned on in production!
 DEBUG = True
-
+TEMPLATE_DEBUG = True
 
 # Serve static/media files for local development:
 SERVE_FILES = True
@@ -36,12 +34,32 @@ DATABASES = {
     }
 }
 print(f'Use Database: {DATABASES["default"]["NAME"]!r}', file=__sys.stderr)
+# _____________________________________________________________________________
+
+# Disable security features, because development server doesn't support HTTPS
+CSRF_COOKIE_SECURE = False
+SESSION_COOKIE_SECURE = False
+SECURE_PROXY_SSL_HEADER = None
+SECURE_SSL_REDIRECT = False
+SECURE_HSTS_PRELOAD = False
+SECURE_HSTS_SECONDS = 0
+SECURE_HSTS_INCLUDE_SUBDOMAINS = False
+
+# _____________________________________________________________________________
+# AlwaysLoggedInAsSuperUser
+
+DEFAULT_USERNAME = 'local-test-superuser'
+DEFAULT_USERPASS = 'test'
+DEFAULT_USEREMAIL = 'nobody@local.intranet'
+
+MIDDLEWARE = MIDDLEWARE.copy()
+MIDDLEWARE.append('inventory_project.tests.middleware.AlwaysLoggedInAsSuperUser')
 
 # _____________________________________________________________________________
 # Django-Debug-Toolbar
 
 INSTALLED_APPS += ['debug_toolbar']
-MIDDLEWARE += ['debug_toolbar.middleware.DebugToolbarMiddleware']
+MIDDLEWARE.append('debug_toolbar.middleware.DebugToolbarMiddleware')
 
 DEBUG_TOOLBAR_PATCH_SETTINGS = True
 from debug_toolbar.settings import CONFIG_DEFAULTS as DEBUG_TOOLBAR_CONFIG  # noqa
