@@ -10,9 +10,13 @@ DATABASES = {
     }
 }
 
-SECRET_KEY = 'No individual secret for tests ;)'
+SECRET_KEY = 'No individual secret... But this settings should only be used in tests ;)'
 
-DEBUG = True
+# Run the tests as on production: Without DBEUG:
+DEBUG = False
+TEMPLATE_DEBUG = False
+
+ALLOWED_HOSTS = ('127.0.0.1', '0.0.0.0', 'localhost')
 
 LOGGING['formatters']['colored']['format'] = (
     '%(log_color)s%(name)s %(levelname)8s %(cut_path)s:%(lineno)-3s %(message)s'
